
:mod:`emir.recipes` --- Reduction Recipes for EMIR
==================================================

.. automodule:: emir.recipes
   :synopsis:  Reduction Recipes for EMIR
   :members:

Recipes for image mode
----------------------

.. automodule:: emir.recipes.image.dither
   :members:

.. automodule:: emir.recipes.image.micro
   :members:

.. automodule:: emir.recipes.image.nodded
   :members:

.. automodule:: emir.recipes.image.stare
   :members:

.. automodule:: emir.recipes.image.shared
   :members:
